# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EniArgs', 'Eni']

@pulumi.input_type
class EniArgs:
    def __init__(__self__, *,
                 delete_on_termination: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_address_count: Optional[pulumi.Input[builtins.int]] = None,
                 ipv6_sets: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 network_interface_name: Optional[pulumi.Input[builtins.str]] = None,
                 port_security_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 primary_ip_address: Optional[pulumi.Input['EniPrimaryIpAddressArgs']] = None,
                 private_ip_sets: Optional[pulumi.Input[Sequence[pulumi.Input['EniPrivateIpSetArgs']]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_private_ip_address_count: Optional[pulumi.Input[builtins.int]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['EniTagArgs']]]] = None):
        """
        The set of arguments for constructing a Eni resource.
        :param pulumi.Input[builtins.bool] delete_on_termination: 是否开启随云服务器实例删除，true为开启，false为不开启。
        :param pulumi.Input[builtins.str] description: 辅助网卡的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头；可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不填默认空字符串。
        :param pulumi.Input[builtins.str] instance_id: 网卡绑定实例的ID，如果网卡未挂载或参数ServiceManaged为true，则InstanceId返回值均为空。
        :param pulumi.Input[builtins.int] ipv6_address_count: 为网卡分配私网IPv6地址的数量，传入该参数，系统会自动从网卡所属子网中，分配相应数量的空闲私网IPv6地址，创建时与IPv6Sets不能同时传入。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ipv6_sets: 网卡的IPv6地址列表，例如[2408::153:3921:XX:XX:7b12:1c5f, 2408:4008:2cf:XX:XX:dd1e:2a22:5ddf]。
        :param pulumi.Input[builtins.str] network_interface_name: 网卡名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不填默认是辅助网卡的ID。
        :param pulumi.Input[builtins.bool] port_security_enabled: 是否为网卡开启源/目的地址检查，开启后，系统会自动阻止源地址或目的地址不是当前网卡的流量，true为开启，false为不开启（默认值）。
        :param pulumi.Input['EniPrimaryIpAddressArgs'] primary_ip_address: 网卡的主私有IPv4地址，不支持修改地址，可以修改公网IP。如果指定，必须是对应子网中的一个空闲的私网IPv4地址，如果不指定，从对应子网中自动分配一个空闲的私网IPv4地址。例如：192.XX.XX.10。
        :param pulumi.Input[builtins.str] project_name: 网卡所属项目的名称。
        :param pulumi.Input[builtins.int] secondary_private_ip_address_count: 为辅助网卡自动分配辅助私网IPv4地址数量，取值1~49。创建时不能与PrivateIpSets同时传入。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 辅助网卡加入一个或多个安全组的ID。
        :param pulumi.Input[builtins.str] subnet_id: 辅助网卡所在子网的ID。
        """
        if delete_on_termination is not None:
            pulumi.set(__self__, "delete_on_termination", delete_on_termination)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if ipv6_address_count is not None:
            pulumi.set(__self__, "ipv6_address_count", ipv6_address_count)
        if ipv6_sets is not None:
            pulumi.set(__self__, "ipv6_sets", ipv6_sets)
        if network_interface_name is not None:
            pulumi.set(__self__, "network_interface_name", network_interface_name)
        if port_security_enabled is not None:
            pulumi.set(__self__, "port_security_enabled", port_security_enabled)
        if primary_ip_address is not None:
            pulumi.set(__self__, "primary_ip_address", primary_ip_address)
        if private_ip_sets is not None:
            pulumi.set(__self__, "private_ip_sets", private_ip_sets)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if secondary_private_ip_address_count is not None:
            pulumi.set(__self__, "secondary_private_ip_address_count", secondary_private_ip_address_count)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="deleteOnTermination")
    def delete_on_termination(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启随云服务器实例删除，true为开启，false为不开启。
        """
        return pulumi.get(self, "delete_on_termination")

    @delete_on_termination.setter
    def delete_on_termination(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "delete_on_termination", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        辅助网卡的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头；可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不填默认空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡绑定实例的ID，如果网卡未挂载或参数ServiceManaged为true，则InstanceId返回值均为空。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="ipv6AddressCount")
    def ipv6_address_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        为网卡分配私网IPv6地址的数量，传入该参数，系统会自动从网卡所属子网中，分配相应数量的空闲私网IPv6地址，创建时与IPv6Sets不能同时传入。
        """
        return pulumi.get(self, "ipv6_address_count")

    @ipv6_address_count.setter
    def ipv6_address_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ipv6_address_count", value)

    @property
    @pulumi.getter(name="ipv6Sets")
    def ipv6_sets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        网卡的IPv6地址列表，例如[2408::153:3921:XX:XX:7b12:1c5f, 2408:4008:2cf:XX:XX:dd1e:2a22:5ddf]。
        """
        return pulumi.get(self, "ipv6_sets")

    @ipv6_sets.setter
    def ipv6_sets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ipv6_sets", value)

    @property
    @pulumi.getter(name="networkInterfaceName")
    def network_interface_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不填默认是辅助网卡的ID。
        """
        return pulumi.get(self, "network_interface_name")

    @network_interface_name.setter
    def network_interface_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_interface_name", value)

    @property
    @pulumi.getter(name="portSecurityEnabled")
    def port_security_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否为网卡开启源/目的地址检查，开启后，系统会自动阻止源地址或目的地址不是当前网卡的流量，true为开启，false为不开启（默认值）。
        """
        return pulumi.get(self, "port_security_enabled")

    @port_security_enabled.setter
    def port_security_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "port_security_enabled", value)

    @property
    @pulumi.getter(name="primaryIpAddress")
    def primary_ip_address(self) -> Optional[pulumi.Input['EniPrimaryIpAddressArgs']]:
        """
        网卡的主私有IPv4地址，不支持修改地址，可以修改公网IP。如果指定，必须是对应子网中的一个空闲的私网IPv4地址，如果不指定，从对应子网中自动分配一个空闲的私网IPv4地址。例如：192.XX.XX.10。
        """
        return pulumi.get(self, "primary_ip_address")

    @primary_ip_address.setter
    def primary_ip_address(self, value: Optional[pulumi.Input['EniPrimaryIpAddressArgs']]):
        pulumi.set(self, "primary_ip_address", value)

    @property
    @pulumi.getter(name="privateIpSets")
    def private_ip_sets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EniPrivateIpSetArgs']]]]:
        return pulumi.get(self, "private_ip_sets")

    @private_ip_sets.setter
    def private_ip_sets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EniPrivateIpSetArgs']]]]):
        pulumi.set(self, "private_ip_sets", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="secondaryPrivateIpAddressCount")
    def secondary_private_ip_address_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        为辅助网卡自动分配辅助私网IPv4地址数量，取值1~49。创建时不能与PrivateIpSets同时传入。
        """
        return pulumi.get(self, "secondary_private_ip_address_count")

    @secondary_private_ip_address_count.setter
    def secondary_private_ip_address_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "secondary_private_ip_address_count", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        辅助网卡加入一个或多个安全组的ID。
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        辅助网卡所在子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EniTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EniTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _EniState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 delete_on_termination: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_address_count: Optional[pulumi.Input[builtins.int]] = None,
                 ipv6_sets: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 mac_address: Optional[pulumi.Input[builtins.str]] = None,
                 network_interface_id: Optional[pulumi.Input[builtins.str]] = None,
                 network_interface_name: Optional[pulumi.Input[builtins.str]] = None,
                 port_security_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 primary_ip_address: Optional[pulumi.Input['EniPrimaryIpAddressArgs']] = None,
                 private_ip_sets: Optional[pulumi.Input[Sequence[pulumi.Input['EniPrivateIpSetArgs']]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_private_ip_address_count: Optional[pulumi.Input[builtins.int]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_managed: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['EniTagArgs']]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_name: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Eni resources.
        :param pulumi.Input[builtins.str] account_id: 网卡所有者ID。
        :param pulumi.Input[builtins.str] created_time: 网卡创建时间。
        :param pulumi.Input[builtins.bool] delete_on_termination: 是否开启随云服务器实例删除，true为开启，false为不开启。
        :param pulumi.Input[builtins.str] description: 辅助网卡的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头；可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不填默认空字符串。
        :param pulumi.Input[builtins.str] instance_id: 网卡绑定实例的ID，如果网卡未挂载或参数ServiceManaged为true，则InstanceId返回值均为空。
        :param pulumi.Input[builtins.int] ipv6_address_count: 为网卡分配私网IPv6地址的数量，传入该参数，系统会自动从网卡所属子网中，分配相应数量的空闲私网IPv6地址，创建时与IPv6Sets不能同时传入。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ipv6_sets: 网卡的IPv6地址列表，例如[2408::153:3921:XX:XX:7b12:1c5f, 2408:4008:2cf:XX:XX:dd1e:2a22:5ddf]。
        :param pulumi.Input[builtins.str] mac_address: 网卡的MAC地址。
        :param pulumi.Input[builtins.str] network_interface_id: 网卡ID。
        :param pulumi.Input[builtins.str] network_interface_name: 网卡名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不填默认是辅助网卡的ID。
        :param pulumi.Input[builtins.bool] port_security_enabled: 是否为网卡开启源/目的地址检查，开启后，系统会自动阻止源地址或目的地址不是当前网卡的流量，true为开启，false为不开启（默认值）。
        :param pulumi.Input['EniPrimaryIpAddressArgs'] primary_ip_address: 网卡的主私有IPv4地址，不支持修改地址，可以修改公网IP。如果指定，必须是对应子网中的一个空闲的私网IPv4地址，如果不指定，从对应子网中自动分配一个空闲的私网IPv4地址。例如：192.XX.XX.10。
        :param pulumi.Input[builtins.str] project_name: 网卡所属项目的名称。
        :param pulumi.Input[builtins.int] secondary_private_ip_address_count: 为辅助网卡自动分配辅助私网IPv4地址数量，取值1~49。创建时不能与PrivateIpSets同时传入。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 辅助网卡加入一个或多个安全组的ID。
        :param pulumi.Input[builtins.bool] service_managed: 是否为官方服务网卡，true为是，false为否。
        :param pulumi.Input[builtins.str] status: 网卡的绑定状态。Creating：创建中。Available：未挂载。Attaching：挂载中。InUse：已挂载。Detaching：卸载中。Deleting：删除中。
        :param pulumi.Input[builtins.str] subnet_id: 辅助网卡所在子网的ID。
        :param pulumi.Input[builtins.str] type: 网卡类型。primary：主网卡，secondary：辅助网卡
        :param pulumi.Input[builtins.str] updated_time: 更新网卡的时间。
        :param pulumi.Input[builtins.str] vpc_id: 网卡所属的VPC的ID。
        :param pulumi.Input[builtins.str] vpc_name: 网卡所属VPC的名称。
        :param pulumi.Input[builtins.str] zone_id: 网卡所属可用区的ID。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if delete_on_termination is not None:
            pulumi.set(__self__, "delete_on_termination", delete_on_termination)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if ipv6_address_count is not None:
            pulumi.set(__self__, "ipv6_address_count", ipv6_address_count)
        if ipv6_sets is not None:
            pulumi.set(__self__, "ipv6_sets", ipv6_sets)
        if mac_address is not None:
            pulumi.set(__self__, "mac_address", mac_address)
        if network_interface_id is not None:
            pulumi.set(__self__, "network_interface_id", network_interface_id)
        if network_interface_name is not None:
            pulumi.set(__self__, "network_interface_name", network_interface_name)
        if port_security_enabled is not None:
            pulumi.set(__self__, "port_security_enabled", port_security_enabled)
        if primary_ip_address is not None:
            pulumi.set(__self__, "primary_ip_address", primary_ip_address)
        if private_ip_sets is not None:
            pulumi.set(__self__, "private_ip_sets", private_ip_sets)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if secondary_private_ip_address_count is not None:
            pulumi.set(__self__, "secondary_private_ip_address_count", secondary_private_ip_address_count)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if service_managed is not None:
            pulumi.set(__self__, "service_managed", service_managed)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_name is not None:
            pulumi.set(__self__, "vpc_name", vpc_name)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡所有者ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="deleteOnTermination")
    def delete_on_termination(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启随云服务器实例删除，true为开启，false为不开启。
        """
        return pulumi.get(self, "delete_on_termination")

    @delete_on_termination.setter
    def delete_on_termination(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "delete_on_termination", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        辅助网卡的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头；可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不填默认空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡绑定实例的ID，如果网卡未挂载或参数ServiceManaged为true，则InstanceId返回值均为空。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="ipv6AddressCount")
    def ipv6_address_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        为网卡分配私网IPv6地址的数量，传入该参数，系统会自动从网卡所属子网中，分配相应数量的空闲私网IPv6地址，创建时与IPv6Sets不能同时传入。
        """
        return pulumi.get(self, "ipv6_address_count")

    @ipv6_address_count.setter
    def ipv6_address_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ipv6_address_count", value)

    @property
    @pulumi.getter(name="ipv6Sets")
    def ipv6_sets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        网卡的IPv6地址列表，例如[2408::153:3921:XX:XX:7b12:1c5f, 2408:4008:2cf:XX:XX:dd1e:2a22:5ddf]。
        """
        return pulumi.get(self, "ipv6_sets")

    @ipv6_sets.setter
    def ipv6_sets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ipv6_sets", value)

    @property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡的MAC地址。
        """
        return pulumi.get(self, "mac_address")

    @mac_address.setter
    def mac_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mac_address", value)

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡ID。
        """
        return pulumi.get(self, "network_interface_id")

    @network_interface_id.setter
    def network_interface_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_interface_id", value)

    @property
    @pulumi.getter(name="networkInterfaceName")
    def network_interface_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不填默认是辅助网卡的ID。
        """
        return pulumi.get(self, "network_interface_name")

    @network_interface_name.setter
    def network_interface_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_interface_name", value)

    @property
    @pulumi.getter(name="portSecurityEnabled")
    def port_security_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否为网卡开启源/目的地址检查，开启后，系统会自动阻止源地址或目的地址不是当前网卡的流量，true为开启，false为不开启（默认值）。
        """
        return pulumi.get(self, "port_security_enabled")

    @port_security_enabled.setter
    def port_security_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "port_security_enabled", value)

    @property
    @pulumi.getter(name="primaryIpAddress")
    def primary_ip_address(self) -> Optional[pulumi.Input['EniPrimaryIpAddressArgs']]:
        """
        网卡的主私有IPv4地址，不支持修改地址，可以修改公网IP。如果指定，必须是对应子网中的一个空闲的私网IPv4地址，如果不指定，从对应子网中自动分配一个空闲的私网IPv4地址。例如：192.XX.XX.10。
        """
        return pulumi.get(self, "primary_ip_address")

    @primary_ip_address.setter
    def primary_ip_address(self, value: Optional[pulumi.Input['EniPrimaryIpAddressArgs']]):
        pulumi.set(self, "primary_ip_address", value)

    @property
    @pulumi.getter(name="privateIpSets")
    def private_ip_sets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EniPrivateIpSetArgs']]]]:
        return pulumi.get(self, "private_ip_sets")

    @private_ip_sets.setter
    def private_ip_sets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EniPrivateIpSetArgs']]]]):
        pulumi.set(self, "private_ip_sets", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="secondaryPrivateIpAddressCount")
    def secondary_private_ip_address_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        为辅助网卡自动分配辅助私网IPv4地址数量，取值1~49。创建时不能与PrivateIpSets同时传入。
        """
        return pulumi.get(self, "secondary_private_ip_address_count")

    @secondary_private_ip_address_count.setter
    def secondary_private_ip_address_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "secondary_private_ip_address_count", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        辅助网卡加入一个或多个安全组的ID。
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter(name="serviceManaged")
    def service_managed(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否为官方服务网卡，true为是，false为否。
        """
        return pulumi.get(self, "service_managed")

    @service_managed.setter
    def service_managed(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "service_managed", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡的绑定状态。Creating：创建中。Available：未挂载。Attaching：挂载中。InUse：已挂载。Detaching：卸载中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        辅助网卡所在子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EniTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EniTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡类型。primary：主网卡，secondary：辅助网卡
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新网卡的时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡所属的VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡所属VPC的名称。
        """
        return pulumi.get(self, "vpc_name")

    @vpc_name.setter
    def vpc_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_name", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网卡所属可用区的ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("bytepluscc:vpc/eni:Eni")
class Eni(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delete_on_termination: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_address_count: Optional[pulumi.Input[builtins.int]] = None,
                 ipv6_sets: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 network_interface_name: Optional[pulumi.Input[builtins.str]] = None,
                 port_security_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 primary_ip_address: Optional[pulumi.Input[Union['EniPrimaryIpAddressArgs', 'EniPrimaryIpAddressArgsDict']]] = None,
                 private_ip_sets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EniPrivateIpSetArgs', 'EniPrivateIpSetArgsDict']]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_private_ip_address_count: Optional[pulumi.Input[builtins.int]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EniTagArgs', 'EniTagArgsDict']]]]] = None,
                 __props__=None):
        """
        网卡即虚拟网卡。在私有网络里，网卡是挂载在云服务器、负载均衡等云资源上的一种网络接口。每张网卡均有一个主私网IP地址。若有需要，可手动为其分配多个辅助私网IP地址。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/eni:Eni example "network_interface_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] delete_on_termination: 是否开启随云服务器实例删除，true为开启，false为不开启。
        :param pulumi.Input[builtins.str] description: 辅助网卡的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头；可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不填默认空字符串。
        :param pulumi.Input[builtins.str] instance_id: 网卡绑定实例的ID，如果网卡未挂载或参数ServiceManaged为true，则InstanceId返回值均为空。
        :param pulumi.Input[builtins.int] ipv6_address_count: 为网卡分配私网IPv6地址的数量，传入该参数，系统会自动从网卡所属子网中，分配相应数量的空闲私网IPv6地址，创建时与IPv6Sets不能同时传入。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ipv6_sets: 网卡的IPv6地址列表，例如[2408::153:3921:XX:XX:7b12:1c5f, 2408:4008:2cf:XX:XX:dd1e:2a22:5ddf]。
        :param pulumi.Input[builtins.str] network_interface_name: 网卡名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不填默认是辅助网卡的ID。
        :param pulumi.Input[builtins.bool] port_security_enabled: 是否为网卡开启源/目的地址检查，开启后，系统会自动阻止源地址或目的地址不是当前网卡的流量，true为开启，false为不开启（默认值）。
        :param pulumi.Input[Union['EniPrimaryIpAddressArgs', 'EniPrimaryIpAddressArgsDict']] primary_ip_address: 网卡的主私有IPv4地址，不支持修改地址，可以修改公网IP。如果指定，必须是对应子网中的一个空闲的私网IPv4地址，如果不指定，从对应子网中自动分配一个空闲的私网IPv4地址。例如：192.XX.XX.10。
        :param pulumi.Input[builtins.str] project_name: 网卡所属项目的名称。
        :param pulumi.Input[builtins.int] secondary_private_ip_address_count: 为辅助网卡自动分配辅助私网IPv4地址数量，取值1~49。创建时不能与PrivateIpSets同时传入。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 辅助网卡加入一个或多个安全组的ID。
        :param pulumi.Input[builtins.str] subnet_id: 辅助网卡所在子网的ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[EniArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        网卡即虚拟网卡。在私有网络里，网卡是挂载在云服务器、负载均衡等云资源上的一种网络接口。每张网卡均有一个主私网IP地址。若有需要，可手动为其分配多个辅助私网IP地址。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/eni:Eni example "network_interface_id"
        ```

        :param str resource_name: The name of the resource.
        :param EniArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EniArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delete_on_termination: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_address_count: Optional[pulumi.Input[builtins.int]] = None,
                 ipv6_sets: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 network_interface_name: Optional[pulumi.Input[builtins.str]] = None,
                 port_security_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 primary_ip_address: Optional[pulumi.Input[Union['EniPrimaryIpAddressArgs', 'EniPrimaryIpAddressArgsDict']]] = None,
                 private_ip_sets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EniPrivateIpSetArgs', 'EniPrivateIpSetArgsDict']]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_private_ip_address_count: Optional[pulumi.Input[builtins.int]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EniTagArgs', 'EniTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EniArgs.__new__(EniArgs)

            __props__.__dict__["delete_on_termination"] = delete_on_termination
            __props__.__dict__["description"] = description
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["ipv6_address_count"] = ipv6_address_count
            __props__.__dict__["ipv6_sets"] = ipv6_sets
            __props__.__dict__["network_interface_name"] = network_interface_name
            __props__.__dict__["port_security_enabled"] = port_security_enabled
            __props__.__dict__["primary_ip_address"] = primary_ip_address
            __props__.__dict__["private_ip_sets"] = private_ip_sets
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["secondary_private_ip_address_count"] = secondary_private_ip_address_count
            __props__.__dict__["security_group_ids"] = security_group_ids
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["account_id"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["mac_address"] = None
            __props__.__dict__["network_interface_id"] = None
            __props__.__dict__["service_managed"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["type"] = None
            __props__.__dict__["updated_time"] = None
            __props__.__dict__["vpc_id"] = None
            __props__.__dict__["vpc_name"] = None
            __props__.__dict__["zone_id"] = None
        super(Eni, __self__).__init__(
            'bytepluscc:vpc/eni:Eni',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            delete_on_termination: Optional[pulumi.Input[builtins.bool]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            ipv6_address_count: Optional[pulumi.Input[builtins.int]] = None,
            ipv6_sets: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            mac_address: Optional[pulumi.Input[builtins.str]] = None,
            network_interface_id: Optional[pulumi.Input[builtins.str]] = None,
            network_interface_name: Optional[pulumi.Input[builtins.str]] = None,
            port_security_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            primary_ip_address: Optional[pulumi.Input[Union['EniPrimaryIpAddressArgs', 'EniPrimaryIpAddressArgsDict']]] = None,
            private_ip_sets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EniPrivateIpSetArgs', 'EniPrivateIpSetArgsDict']]]]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            secondary_private_ip_address_count: Optional[pulumi.Input[builtins.int]] = None,
            security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            service_managed: Optional[pulumi.Input[builtins.bool]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EniTagArgs', 'EniTagArgsDict']]]]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            vpc_name: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Eni':
        """
        Get an existing Eni resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: 网卡所有者ID。
        :param pulumi.Input[builtins.str] created_time: 网卡创建时间。
        :param pulumi.Input[builtins.bool] delete_on_termination: 是否开启随云服务器实例删除，true为开启，false为不开启。
        :param pulumi.Input[builtins.str] description: 辅助网卡的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头；可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不填默认空字符串。
        :param pulumi.Input[builtins.str] instance_id: 网卡绑定实例的ID，如果网卡未挂载或参数ServiceManaged为true，则InstanceId返回值均为空。
        :param pulumi.Input[builtins.int] ipv6_address_count: 为网卡分配私网IPv6地址的数量，传入该参数，系统会自动从网卡所属子网中，分配相应数量的空闲私网IPv6地址，创建时与IPv6Sets不能同时传入。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ipv6_sets: 网卡的IPv6地址列表，例如[2408::153:3921:XX:XX:7b12:1c5f, 2408:4008:2cf:XX:XX:dd1e:2a22:5ddf]。
        :param pulumi.Input[builtins.str] mac_address: 网卡的MAC地址。
        :param pulumi.Input[builtins.str] network_interface_id: 网卡ID。
        :param pulumi.Input[builtins.str] network_interface_name: 网卡名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不填默认是辅助网卡的ID。
        :param pulumi.Input[builtins.bool] port_security_enabled: 是否为网卡开启源/目的地址检查，开启后，系统会自动阻止源地址或目的地址不是当前网卡的流量，true为开启，false为不开启（默认值）。
        :param pulumi.Input[Union['EniPrimaryIpAddressArgs', 'EniPrimaryIpAddressArgsDict']] primary_ip_address: 网卡的主私有IPv4地址，不支持修改地址，可以修改公网IP。如果指定，必须是对应子网中的一个空闲的私网IPv4地址，如果不指定，从对应子网中自动分配一个空闲的私网IPv4地址。例如：192.XX.XX.10。
        :param pulumi.Input[builtins.str] project_name: 网卡所属项目的名称。
        :param pulumi.Input[builtins.int] secondary_private_ip_address_count: 为辅助网卡自动分配辅助私网IPv4地址数量，取值1~49。创建时不能与PrivateIpSets同时传入。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 辅助网卡加入一个或多个安全组的ID。
        :param pulumi.Input[builtins.bool] service_managed: 是否为官方服务网卡，true为是，false为否。
        :param pulumi.Input[builtins.str] status: 网卡的绑定状态。Creating：创建中。Available：未挂载。Attaching：挂载中。InUse：已挂载。Detaching：卸载中。Deleting：删除中。
        :param pulumi.Input[builtins.str] subnet_id: 辅助网卡所在子网的ID。
        :param pulumi.Input[builtins.str] type: 网卡类型。primary：主网卡，secondary：辅助网卡
        :param pulumi.Input[builtins.str] updated_time: 更新网卡的时间。
        :param pulumi.Input[builtins.str] vpc_id: 网卡所属的VPC的ID。
        :param pulumi.Input[builtins.str] vpc_name: 网卡所属VPC的名称。
        :param pulumi.Input[builtins.str] zone_id: 网卡所属可用区的ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EniState.__new__(_EniState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["delete_on_termination"] = delete_on_termination
        __props__.__dict__["description"] = description
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["ipv6_address_count"] = ipv6_address_count
        __props__.__dict__["ipv6_sets"] = ipv6_sets
        __props__.__dict__["mac_address"] = mac_address
        __props__.__dict__["network_interface_id"] = network_interface_id
        __props__.__dict__["network_interface_name"] = network_interface_name
        __props__.__dict__["port_security_enabled"] = port_security_enabled
        __props__.__dict__["primary_ip_address"] = primary_ip_address
        __props__.__dict__["private_ip_sets"] = private_ip_sets
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["secondary_private_ip_address_count"] = secondary_private_ip_address_count
        __props__.__dict__["security_group_ids"] = security_group_ids
        __props__.__dict__["service_managed"] = service_managed
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vpc_name"] = vpc_name
        __props__.__dict__["zone_id"] = zone_id
        return Eni(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        网卡所有者ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        网卡创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deleteOnTermination")
    def delete_on_termination(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启随云服务器实例删除，true为开启，false为不开启。
        """
        return pulumi.get(self, "delete_on_termination")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        辅助网卡的描述信息。长度限制为0~ 255个字符，需要以字母、中文或数字开头；可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。），不填默认空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        网卡绑定实例的ID，如果网卡未挂载或参数ServiceManaged为true，则InstanceId返回值均为空。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="ipv6AddressCount")
    def ipv6_address_count(self) -> pulumi.Output[builtins.int]:
        """
        为网卡分配私网IPv6地址的数量，传入该参数，系统会自动从网卡所属子网中，分配相应数量的空闲私网IPv6地址，创建时与IPv6Sets不能同时传入。
        """
        return pulumi.get(self, "ipv6_address_count")

    @property
    @pulumi.getter(name="ipv6Sets")
    def ipv6_sets(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        网卡的IPv6地址列表，例如[2408::153:3921:XX:XX:7b12:1c5f, 2408:4008:2cf:XX:XX:dd1e:2a22:5ddf]。
        """
        return pulumi.get(self, "ipv6_sets")

    @property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> pulumi.Output[builtins.str]:
        """
        网卡的MAC地址。
        """
        return pulumi.get(self, "mac_address")

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> pulumi.Output[builtins.str]:
        """
        网卡ID。
        """
        return pulumi.get(self, "network_interface_id")

    @property
    @pulumi.getter(name="networkInterfaceName")
    def network_interface_name(self) -> pulumi.Output[builtins.str]:
        """
        网卡名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-），不填默认是辅助网卡的ID。
        """
        return pulumi.get(self, "network_interface_name")

    @property
    @pulumi.getter(name="portSecurityEnabled")
    def port_security_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否为网卡开启源/目的地址检查，开启后，系统会自动阻止源地址或目的地址不是当前网卡的流量，true为开启，false为不开启（默认值）。
        """
        return pulumi.get(self, "port_security_enabled")

    @property
    @pulumi.getter(name="primaryIpAddress")
    def primary_ip_address(self) -> pulumi.Output['outputs.EniPrimaryIpAddress']:
        """
        网卡的主私有IPv4地址，不支持修改地址，可以修改公网IP。如果指定，必须是对应子网中的一个空闲的私网IPv4地址，如果不指定，从对应子网中自动分配一个空闲的私网IPv4地址。例如：192.XX.XX.10。
        """
        return pulumi.get(self, "primary_ip_address")

    @property
    @pulumi.getter(name="privateIpSets")
    def private_ip_sets(self) -> pulumi.Output[Sequence['outputs.EniPrivateIpSet']]:
        return pulumi.get(self, "private_ip_sets")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        网卡所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="secondaryPrivateIpAddressCount")
    def secondary_private_ip_address_count(self) -> pulumi.Output[builtins.int]:
        """
        为辅助网卡自动分配辅助私网IPv4地址数量，取值1~49。创建时不能与PrivateIpSets同时传入。
        """
        return pulumi.get(self, "secondary_private_ip_address_count")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        辅助网卡加入一个或多个安全组的ID。
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter(name="serviceManaged")
    def service_managed(self) -> pulumi.Output[builtins.bool]:
        """
        是否为官方服务网卡，true为是，false为否。
        """
        return pulumi.get(self, "service_managed")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        网卡的绑定状态。Creating：创建中。Available：未挂载。Attaching：挂载中。InUse：已挂载。Detaching：卸载中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        辅助网卡所在子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.EniTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        网卡类型。primary：主网卡，secondary：辅助网卡
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新网卡的时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        网卡所属的VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> pulumi.Output[builtins.str]:
        """
        网卡所属VPC的名称。
        """
        return pulumi.get(self, "vpc_name")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        网卡所属可用区的ID。
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceCapacityArgs',
    'InstanceCapacityArgsDict',
    'InstanceConfigureNodeArgs',
    'InstanceConfigureNodeArgsDict',
    'InstanceInstanceShardArgs',
    'InstanceInstanceShardArgsDict',
    'InstanceInstanceShardServerNodeArgs',
    'InstanceInstanceShardServerNodeArgsDict',
    'InstanceTagArgs',
    'InstanceTagArgsDict',
    'InstanceVisitAddrArgs',
    'InstanceVisitAddrArgsDict',
]

MYPY = False

if not MYPY:
    class InstanceCapacityArgsDict(TypedDict):
        total: NotRequired[pulumi.Input[builtins.int]]
        """
        当前实例的内存总容量。单位：MiB。
        """
        used: NotRequired[pulumi.Input[builtins.int]]
        """
        当前实例已用容量。单位：MiB。
        """
elif False:
    InstanceCapacityArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceCapacityArgs:
    def __init__(__self__, *,
                 total: Optional[pulumi.Input[builtins.int]] = None,
                 used: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.int] total: 当前实例的内存总容量。单位：MiB。
        :param pulumi.Input[builtins.int] used: 当前实例已用容量。单位：MiB。
        """
        if total is not None:
            pulumi.set(__self__, "total", total)
        if used is not None:
            pulumi.set(__self__, "used", used)

    @property
    @pulumi.getter
    def total(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        当前实例的内存总容量。单位：MiB。
        """
        return pulumi.get(self, "total")

    @total.setter
    def total(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "total", value)

    @property
    @pulumi.getter
    def used(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        当前实例已用容量。单位：MiB。
        """
        return pulumi.get(self, "used")

    @used.setter
    def used(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "used", value)


if not MYPY:
    class InstanceConfigureNodeArgsDict(TypedDict):
        az: NotRequired[pulumi.Input[builtins.str]]
        """
        每个节点所属的可用区。
        """
elif False:
    InstanceConfigureNodeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceConfigureNodeArgs:
    def __init__(__self__, *,
                 az: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] az: 每个节点所属的可用区。
        """
        if az is not None:
            pulumi.set(__self__, "az", az)

    @property
    @pulumi.getter
    def az(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        每个节点所属的可用区。
        """
        return pulumi.get(self, "az")

    @az.setter
    def az(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "az", value)


if not MYPY:
    class InstanceInstanceShardArgsDict(TypedDict):
        node_number: NotRequired[pulumi.Input[builtins.int]]
        """
        分片中的节点数量
        """
        server_nodes: NotRequired[pulumi.Input[Sequence[pulumi.Input['InstanceInstanceShardServerNodeArgsDict']]]]
        shard_id: NotRequired[pulumi.Input[builtins.str]]
        """
        分片 ID。
        """
elif False:
    InstanceInstanceShardArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceInstanceShardArgs:
    def __init__(__self__, *,
                 node_number: Optional[pulumi.Input[builtins.int]] = None,
                 server_nodes: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceInstanceShardServerNodeArgs']]]] = None,
                 shard_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.int] node_number: 分片中的节点数量
        :param pulumi.Input[builtins.str] shard_id: 分片 ID。
        """
        if node_number is not None:
            pulumi.set(__self__, "node_number", node_number)
        if server_nodes is not None:
            pulumi.set(__self__, "server_nodes", server_nodes)
        if shard_id is not None:
            pulumi.set(__self__, "shard_id", shard_id)

    @property
    @pulumi.getter(name="nodeNumber")
    def node_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        分片中的节点数量
        """
        return pulumi.get(self, "node_number")

    @node_number.setter
    def node_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "node_number", value)

    @property
    @pulumi.getter(name="serverNodes")
    def server_nodes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceInstanceShardServerNodeArgs']]]]:
        return pulumi.get(self, "server_nodes")

    @server_nodes.setter
    def server_nodes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceInstanceShardServerNodeArgs']]]]):
        pulumi.set(self, "server_nodes", value)

    @property
    @pulumi.getter(name="shardId")
    def shard_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        分片 ID。
        """
        return pulumi.get(self, "shard_id")

    @shard_id.setter
    def shard_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "shard_id", value)


if not MYPY:
    class InstanceInstanceShardServerNodeArgsDict(TypedDict):
        current_role: NotRequired[pulumi.Input[builtins.str]]
        """
        节点当前的角色。取值范围如下：PrimaryNode：主节点。SecondaryNode：从节点。
        """
        node_id: NotRequired[pulumi.Input[builtins.str]]
        """
        节点 ID。
        """
        status: NotRequired[pulumi.Input[builtins.str]]
        """
        节点状态。取值范围如下：deploy：启动中。running：运行中。loading：数据加载中。error：错误。
        """
        zone_id: NotRequired[pulumi.Input[builtins.str]]
        """
        节点所在的可用区。
        """
elif False:
    InstanceInstanceShardServerNodeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceInstanceShardServerNodeArgs:
    def __init__(__self__, *,
                 current_role: Optional[pulumi.Input[builtins.str]] = None,
                 node_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] current_role: 节点当前的角色。取值范围如下：PrimaryNode：主节点。SecondaryNode：从节点。
        :param pulumi.Input[builtins.str] node_id: 节点 ID。
        :param pulumi.Input[builtins.str] status: 节点状态。取值范围如下：deploy：启动中。running：运行中。loading：数据加载中。error：错误。
        :param pulumi.Input[builtins.str] zone_id: 节点所在的可用区。
        """
        if current_role is not None:
            pulumi.set(__self__, "current_role", current_role)
        if node_id is not None:
            pulumi.set(__self__, "node_id", node_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="currentRole")
    def current_role(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点当前的角色。取值范围如下：PrimaryNode：主节点。SecondaryNode：从节点。
        """
        return pulumi.get(self, "current_role")

    @current_role.setter
    def current_role(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "current_role", value)

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点 ID。
        """
        return pulumi.get(self, "node_id")

    @node_id.setter
    def node_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "node_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点状态。取值范围如下：deploy：启动中。running：运行中。loading：数据加载中。error：错误。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点所在的可用区。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


if not MYPY:
    class InstanceTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    InstanceTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class InstanceVisitAddrArgsDict(TypedDict):
        addr_type: NotRequired[pulumi.Input[builtins.str]]
        """
        连接地址类型，取值范围如下：Private：私网连接地址；Public：公网连接地址；DirectLink：直连地址。
        """
        address: NotRequired[pulumi.Input[builtins.str]]
        """
        IP 地址或者域名。
        """
        eip_id: NotRequired[pulumi.Input[builtins.str]]
        """
        实例公网地址所绑定的EIP ID。仅当连接地址类型（即AddrType）为Public公网连接地址时，返回该参数。
        """
        port: NotRequired[pulumi.Input[builtins.str]]
        """
        端口号。
        """
        vi_pv6: NotRequired[pulumi.Input[builtins.str]]
        """
        连接地址所对应的 IPv6 地址。
        """
        vip: NotRequired[pulumi.Input[builtins.str]]
        """
        连接地址所对应的 IPv4 地址。
        """
elif False:
    InstanceVisitAddrArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceVisitAddrArgs:
    def __init__(__self__, *,
                 addr_type: Optional[pulumi.Input[builtins.str]] = None,
                 address: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.str]] = None,
                 vi_pv6: Optional[pulumi.Input[builtins.str]] = None,
                 vip: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] addr_type: 连接地址类型，取值范围如下：Private：私网连接地址；Public：公网连接地址；DirectLink：直连地址。
        :param pulumi.Input[builtins.str] address: IP 地址或者域名。
        :param pulumi.Input[builtins.str] eip_id: 实例公网地址所绑定的EIP ID。仅当连接地址类型（即AddrType）为Public公网连接地址时，返回该参数。
        :param pulumi.Input[builtins.str] port: 端口号。
        :param pulumi.Input[builtins.str] vi_pv6: 连接地址所对应的 IPv6 地址。
        :param pulumi.Input[builtins.str] vip: 连接地址所对应的 IPv4 地址。
        """
        if addr_type is not None:
            pulumi.set(__self__, "addr_type", addr_type)
        if address is not None:
            pulumi.set(__self__, "address", address)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if vi_pv6 is not None:
            pulumi.set(__self__, "vi_pv6", vi_pv6)
        if vip is not None:
            pulumi.set(__self__, "vip", vip)

    @property
    @pulumi.getter(name="addrType")
    def addr_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接地址类型，取值范围如下：Private：私网连接地址；Public：公网连接地址；DirectLink：直连地址。
        """
        return pulumi.get(self, "addr_type")

    @addr_type.setter
    def addr_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "addr_type", value)

    @property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP 地址或者域名。
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例公网地址所绑定的EIP ID。仅当连接地址类型（即AddrType）为Public公网连接地址时，返回该参数。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        端口号。
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="viPv6")
    def vi_pv6(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接地址所对应的 IPv6 地址。
        """
        return pulumi.get(self, "vi_pv6")

    @vi_pv6.setter
    def vi_pv6(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vi_pv6", value)

    @property
    @pulumi.getter
    def vip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接地址所对应的 IPv4 地址。
        """
        return pulumi.get(self, "vip")

    @vip.setter
    def vip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vip", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetScalingGroupResult',
    'AwaitableGetScalingGroupResult',
    'get_scaling_group',
    'get_scaling_group_output',
]

@pulumi.output_type
class GetScalingGroupResult:
    """
    A collection of values returned by getScalingGroup.
    """
    def __init__(__self__, active_scaling_configuration_id=None, created_time=None, db_instance_ids=None, default_cooldown=None, desire_instance_number=None, health_check_type=None, id=None, instance_terminate_policy=None, instances_distribution=None, is_enable_scaling_group=None, launch_template_id=None, launch_template_overrides=None, launch_template_version=None, lifecycle_state=None, load_balancer_health_check_grace_period=None, max_instance_number=None, min_instance_number=None, multi_az_policy=None, project_name=None, scaling_group_id=None, scaling_group_name=None, scaling_mode=None, server_group_attributes=None, stopped_instance_count=None, subnet_ids=None, suspended_processes=None, tags=None, total_instance_count=None, updated_time=None, vpc_id=None):
        if active_scaling_configuration_id and not isinstance(active_scaling_configuration_id, str):
            raise TypeError("Expected argument 'active_scaling_configuration_id' to be a str")
        pulumi.set(__self__, "active_scaling_configuration_id", active_scaling_configuration_id)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if db_instance_ids and not isinstance(db_instance_ids, list):
            raise TypeError("Expected argument 'db_instance_ids' to be a list")
        pulumi.set(__self__, "db_instance_ids", db_instance_ids)
        if default_cooldown and not isinstance(default_cooldown, int):
            raise TypeError("Expected argument 'default_cooldown' to be a int")
        pulumi.set(__self__, "default_cooldown", default_cooldown)
        if desire_instance_number and not isinstance(desire_instance_number, int):
            raise TypeError("Expected argument 'desire_instance_number' to be a int")
        pulumi.set(__self__, "desire_instance_number", desire_instance_number)
        if health_check_type and not isinstance(health_check_type, str):
            raise TypeError("Expected argument 'health_check_type' to be a str")
        pulumi.set(__self__, "health_check_type", health_check_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_terminate_policy and not isinstance(instance_terminate_policy, str):
            raise TypeError("Expected argument 'instance_terminate_policy' to be a str")
        pulumi.set(__self__, "instance_terminate_policy", instance_terminate_policy)
        if instances_distribution and not isinstance(instances_distribution, dict):
            raise TypeError("Expected argument 'instances_distribution' to be a dict")
        pulumi.set(__self__, "instances_distribution", instances_distribution)
        if is_enable_scaling_group and not isinstance(is_enable_scaling_group, bool):
            raise TypeError("Expected argument 'is_enable_scaling_group' to be a bool")
        pulumi.set(__self__, "is_enable_scaling_group", is_enable_scaling_group)
        if launch_template_id and not isinstance(launch_template_id, str):
            raise TypeError("Expected argument 'launch_template_id' to be a str")
        pulumi.set(__self__, "launch_template_id", launch_template_id)
        if launch_template_overrides and not isinstance(launch_template_overrides, list):
            raise TypeError("Expected argument 'launch_template_overrides' to be a list")
        pulumi.set(__self__, "launch_template_overrides", launch_template_overrides)
        if launch_template_version and not isinstance(launch_template_version, str):
            raise TypeError("Expected argument 'launch_template_version' to be a str")
        pulumi.set(__self__, "launch_template_version", launch_template_version)
        if lifecycle_state and not isinstance(lifecycle_state, str):
            raise TypeError("Expected argument 'lifecycle_state' to be a str")
        pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if load_balancer_health_check_grace_period and not isinstance(load_balancer_health_check_grace_period, int):
            raise TypeError("Expected argument 'load_balancer_health_check_grace_period' to be a int")
        pulumi.set(__self__, "load_balancer_health_check_grace_period", load_balancer_health_check_grace_period)
        if max_instance_number and not isinstance(max_instance_number, int):
            raise TypeError("Expected argument 'max_instance_number' to be a int")
        pulumi.set(__self__, "max_instance_number", max_instance_number)
        if min_instance_number and not isinstance(min_instance_number, int):
            raise TypeError("Expected argument 'min_instance_number' to be a int")
        pulumi.set(__self__, "min_instance_number", min_instance_number)
        if multi_az_policy and not isinstance(multi_az_policy, str):
            raise TypeError("Expected argument 'multi_az_policy' to be a str")
        pulumi.set(__self__, "multi_az_policy", multi_az_policy)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if scaling_group_id and not isinstance(scaling_group_id, str):
            raise TypeError("Expected argument 'scaling_group_id' to be a str")
        pulumi.set(__self__, "scaling_group_id", scaling_group_id)
        if scaling_group_name and not isinstance(scaling_group_name, str):
            raise TypeError("Expected argument 'scaling_group_name' to be a str")
        pulumi.set(__self__, "scaling_group_name", scaling_group_name)
        if scaling_mode and not isinstance(scaling_mode, str):
            raise TypeError("Expected argument 'scaling_mode' to be a str")
        pulumi.set(__self__, "scaling_mode", scaling_mode)
        if server_group_attributes and not isinstance(server_group_attributes, list):
            raise TypeError("Expected argument 'server_group_attributes' to be a list")
        pulumi.set(__self__, "server_group_attributes", server_group_attributes)
        if stopped_instance_count and not isinstance(stopped_instance_count, int):
            raise TypeError("Expected argument 'stopped_instance_count' to be a int")
        pulumi.set(__self__, "stopped_instance_count", stopped_instance_count)
        if subnet_ids and not isinstance(subnet_ids, list):
            raise TypeError("Expected argument 'subnet_ids' to be a list")
        pulumi.set(__self__, "subnet_ids", subnet_ids)
        if suspended_processes and not isinstance(suspended_processes, list):
            raise TypeError("Expected argument 'suspended_processes' to be a list")
        pulumi.set(__self__, "suspended_processes", suspended_processes)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if total_instance_count and not isinstance(total_instance_count, int):
            raise TypeError("Expected argument 'total_instance_count' to be a int")
        pulumi.set(__self__, "total_instance_count", total_instance_count)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="activeScalingConfigurationId")
    def active_scaling_configuration_id(self) -> builtins.str:
        """
        伸缩组绑定的伸缩配置的ID。
        """
        return pulumi.get(self, "active_scaling_configuration_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        伸缩组创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="dbInstanceIds")
    def db_instance_ids(self) -> Sequence[builtins.str]:
        """
        RDS数据库实例的ID。
        """
        return pulumi.get(self, "db_instance_ids")

    @property
    @pulumi.getter(name="defaultCooldown")
    def default_cooldown(self) -> builtins.int:
        """
        执行一次伸缩活动（添加或移出ECS实例）结束后的冷却时间。冷却时间内，该伸缩组不执行其它的伸缩活动，仅针对云监控报警任务触发的伸缩活动和伸缩规则有效。取值范围：5 ~ 86400，单位：秒。默认值：300。
        """
        return pulumi.get(self, "default_cooldown")

    @property
    @pulumi.getter(name="desireInstanceNumber")
    def desire_instance_number(self) -> builtins.int:
        """
        伸缩组中期望运行的实例个数。1、不小于最小实例数MinInstanceNumber且不大于最大实例数MaxInstanceNumber。2、默认值：-1，表示不开启期望实例数能力。此时，伸缩组创建完成后会立即开始伸缩活动自动添加相应个数的实例。
        """
        return pulumi.get(self, "desire_instance_number")

    @property
    @pulumi.getter(name="healthCheckType")
    def health_check_type(self) -> builtins.str:
        """
        伸缩组的健康检查方式。1、NONE：不做实例健康状态检查。2、ECS（默认）：对伸缩组内的ECS实例做健康检查。
        """
        return pulumi.get(self, "health_check_type")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceTerminatePolicy")
    def instance_terminate_policy(self) -> builtins.str:
        """
        实例移除策略，1、OldestInstance：移出最早加入 （包括自动创建和手动添加）伸缩组的实例。2、NewestInstance：移出最晚加入（包括自动创建和手动添加）伸缩组的实例。3、OldestScalingConfigurationWithOldestInstance（默认）：移出最早与伸缩组绑定的伸缩配置中，最早由伸缩组 自动创建 的实例。4、OldestScalingConfigurationWithNewestInstance：移出最早与伸缩组绑定的伸缩配置中，最晚由伸缩组 自动创建 的实例。
        """
        return pulumi.get(self, "instance_terminate_policy")

    @property
    @pulumi.getter(name="instancesDistribution")
    def instances_distribution(self) -> 'outputs.GetScalingGroupInstancesDistributionResult':
        """
        实例分布策略。
        """
        return pulumi.get(self, "instances_distribution")

    @property
    @pulumi.getter(name="isEnableScalingGroup")
    def is_enable_scaling_group(self) -> builtins.bool:
        """
        是否启用伸缩组。true：启用。false：停止
        """
        return pulumi.get(self, "is_enable_scaling_group")

    @property
    @pulumi.getter(name="launchTemplateId")
    def launch_template_id(self) -> builtins.str:
        """
        实例启动模板ID，配置后表示选择启动模版作为伸缩配置来源。
        """
        return pulumi.get(self, "launch_template_id")

    @property
    @pulumi.getter(name="launchTemplateOverrides")
    def launch_template_overrides(self) -> Sequence['outputs.GetScalingGroupLaunchTemplateOverrideResult']:
        """
        实例启动模版信息。
        """
        return pulumi.get(self, "launch_template_overrides")

    @property
    @pulumi.getter(name="launchTemplateVersion")
    def launch_template_version(self) -> builtins.str:
        """
        实例启动模板的版本。1、模板的某个版本号。2、Default（默认）：始终使用模板默认版本。3、Latest：始终使用模板最新版本。
        """
        return pulumi.get(self, "launch_template_version")

    @property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> builtins.str:
        """
        伸缩组的状态。Active：已启用。InActive：未激活。Deleting：删除中。Locked: 已锁定。CoolingDown: 冷却中。Unknown: 未知状态。
        """
        return pulumi.get(self, "lifecycle_state")

    @property
    @pulumi.getter(name="loadBalancerHealthCheckGracePeriod")
    def load_balancer_health_check_grace_period(self) -> builtins.int:
        """
        伸缩组实例CLB健康状况检查宽限期。
        """
        return pulumi.get(self, "load_balancer_health_check_grace_period")

    @property
    @pulumi.getter(name="maxInstanceNumber")
    def max_instance_number(self) -> builtins.int:
        """
        伸缩组中实例个数的最大值，默认取值0 ～ 100。您可以通过配额中心调整。
        """
        return pulumi.get(self, "max_instance_number")

    @property
    @pulumi.getter(name="minInstanceNumber")
    def min_instance_number(self) -> builtins.int:
        """
        伸缩组中实例个数的最小值，默认取值0 ～ 100。您可以通过配额中心调整。
        """
        return pulumi.get(self, "min_instance_number")

    @property
    @pulumi.getter(name="multiAzPolicy")
    def multi_az_policy(self) -> builtins.str:
        """
        扩缩容策略，如果您选择了多个子网，需配置本参数。1、PRIORITY（默认）：优先级策略。2、BALANCE：均衡分布策略。
        """
        return pulumi.get(self, "multi_az_policy")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        伸缩组所属项目，默认为default。一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> builtins.str:
        """
        伸缩组ID。
        """
        return pulumi.get(self, "scaling_group_id")

    @property
    @pulumi.getter(name="scalingGroupName")
    def scaling_group_name(self) -> builtins.str:
        """
        伸缩组名称，同一地域下伸缩组名称唯一。只能以中文、字母开头，只能包含中文、字母、数字、下划线和中划线 。长度限制为1 ~ 128个字符。暂不支持特殊字符。
        """
        return pulumi.get(self, "scaling_group_name")

    @property
    @pulumi.getter(name="scalingMode")
    def scaling_mode(self) -> builtins.str:
        """
        伸缩组的实例回收模式。1、release（默认）：释放模式。2、recycle：停机回收模式。
        """
        return pulumi.get(self, "scaling_mode")

    @property
    @pulumi.getter(name="serverGroupAttributes")
    def server_group_attributes(self) -> Sequence['outputs.GetScalingGroupServerGroupAttributeResult']:
        """
        伸缩组关联的负载均衡信息。
        """
        return pulumi.get(self, "server_group_attributes")

    @property
    @pulumi.getter(name="stoppedInstanceCount")
    def stopped_instance_count(self) -> builtins.int:
        """
        伸缩组内处于停用中状态的实例数量。
        """
        return pulumi.get(self, "stopped_instance_count")

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> Sequence[builtins.str]:
        """
        伸缩组中实例主网卡的子网ID列表。
        """
        return pulumi.get(self, "subnet_ids")

    @property
    @pulumi.getter(name="suspendedProcesses")
    def suspended_processes(self) -> Sequence[builtins.str]:
        """
        暂停中的流程，无暂停中流程则返回空值。ScaleIn：缩容流程。ScaleOut：扩容流程。HealthCheck：健康检查。AlarmNotification：报警任务。ScheduledAction：定时任务。
        """
        return pulumi.get(self, "suspended_processes")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetScalingGroupTagResult']:
        """
        标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="totalInstanceCount")
    def total_instance_count(self) -> builtins.int:
        """
        当前伸缩组内实例的个数。
        """
        return pulumi.get(self, "total_instance_count")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        伸缩组更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        伸缩组所属私有网络ID。
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetScalingGroupResult(GetScalingGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetScalingGroupResult(
            active_scaling_configuration_id=self.active_scaling_configuration_id,
            created_time=self.created_time,
            db_instance_ids=self.db_instance_ids,
            default_cooldown=self.default_cooldown,
            desire_instance_number=self.desire_instance_number,
            health_check_type=self.health_check_type,
            id=self.id,
            instance_terminate_policy=self.instance_terminate_policy,
            instances_distribution=self.instances_distribution,
            is_enable_scaling_group=self.is_enable_scaling_group,
            launch_template_id=self.launch_template_id,
            launch_template_overrides=self.launch_template_overrides,
            launch_template_version=self.launch_template_version,
            lifecycle_state=self.lifecycle_state,
            load_balancer_health_check_grace_period=self.load_balancer_health_check_grace_period,
            max_instance_number=self.max_instance_number,
            min_instance_number=self.min_instance_number,
            multi_az_policy=self.multi_az_policy,
            project_name=self.project_name,
            scaling_group_id=self.scaling_group_id,
            scaling_group_name=self.scaling_group_name,
            scaling_mode=self.scaling_mode,
            server_group_attributes=self.server_group_attributes,
            stopped_instance_count=self.stopped_instance_count,
            subnet_ids=self.subnet_ids,
            suspended_processes=self.suspended_processes,
            tags=self.tags,
            total_instance_count=self.total_instance_count,
            updated_time=self.updated_time,
            vpc_id=self.vpc_id)


def get_scaling_group(id: Optional[builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetScalingGroupResult:
    """
    Data Source schema for Byteplus::AutoScaling::ScalingGroup


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:autoscaling/getScalingGroup:getScalingGroup', __args__, opts=opts, typ=GetScalingGroupResult).value

    return AwaitableGetScalingGroupResult(
        active_scaling_configuration_id=pulumi.get(__ret__, 'active_scaling_configuration_id'),
        created_time=pulumi.get(__ret__, 'created_time'),
        db_instance_ids=pulumi.get(__ret__, 'db_instance_ids'),
        default_cooldown=pulumi.get(__ret__, 'default_cooldown'),
        desire_instance_number=pulumi.get(__ret__, 'desire_instance_number'),
        health_check_type=pulumi.get(__ret__, 'health_check_type'),
        id=pulumi.get(__ret__, 'id'),
        instance_terminate_policy=pulumi.get(__ret__, 'instance_terminate_policy'),
        instances_distribution=pulumi.get(__ret__, 'instances_distribution'),
        is_enable_scaling_group=pulumi.get(__ret__, 'is_enable_scaling_group'),
        launch_template_id=pulumi.get(__ret__, 'launch_template_id'),
        launch_template_overrides=pulumi.get(__ret__, 'launch_template_overrides'),
        launch_template_version=pulumi.get(__ret__, 'launch_template_version'),
        lifecycle_state=pulumi.get(__ret__, 'lifecycle_state'),
        load_balancer_health_check_grace_period=pulumi.get(__ret__, 'load_balancer_health_check_grace_period'),
        max_instance_number=pulumi.get(__ret__, 'max_instance_number'),
        min_instance_number=pulumi.get(__ret__, 'min_instance_number'),
        multi_az_policy=pulumi.get(__ret__, 'multi_az_policy'),
        project_name=pulumi.get(__ret__, 'project_name'),
        scaling_group_id=pulumi.get(__ret__, 'scaling_group_id'),
        scaling_group_name=pulumi.get(__ret__, 'scaling_group_name'),
        scaling_mode=pulumi.get(__ret__, 'scaling_mode'),
        server_group_attributes=pulumi.get(__ret__, 'server_group_attributes'),
        stopped_instance_count=pulumi.get(__ret__, 'stopped_instance_count'),
        subnet_ids=pulumi.get(__ret__, 'subnet_ids'),
        suspended_processes=pulumi.get(__ret__, 'suspended_processes'),
        tags=pulumi.get(__ret__, 'tags'),
        total_instance_count=pulumi.get(__ret__, 'total_instance_count'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_scaling_group_output(id: Optional[pulumi.Input[builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetScalingGroupResult]:
    """
    Data Source schema for Byteplus::AutoScaling::ScalingGroup


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:autoscaling/getScalingGroup:getScalingGroup', __args__, opts=opts, typ=GetScalingGroupResult)
    return __ret__.apply(lambda __response__: GetScalingGroupResult(
        active_scaling_configuration_id=pulumi.get(__response__, 'active_scaling_configuration_id'),
        created_time=pulumi.get(__response__, 'created_time'),
        db_instance_ids=pulumi.get(__response__, 'db_instance_ids'),
        default_cooldown=pulumi.get(__response__, 'default_cooldown'),
        desire_instance_number=pulumi.get(__response__, 'desire_instance_number'),
        health_check_type=pulumi.get(__response__, 'health_check_type'),
        id=pulumi.get(__response__, 'id'),
        instance_terminate_policy=pulumi.get(__response__, 'instance_terminate_policy'),
        instances_distribution=pulumi.get(__response__, 'instances_distribution'),
        is_enable_scaling_group=pulumi.get(__response__, 'is_enable_scaling_group'),
        launch_template_id=pulumi.get(__response__, 'launch_template_id'),
        launch_template_overrides=pulumi.get(__response__, 'launch_template_overrides'),
        launch_template_version=pulumi.get(__response__, 'launch_template_version'),
        lifecycle_state=pulumi.get(__response__, 'lifecycle_state'),
        load_balancer_health_check_grace_period=pulumi.get(__response__, 'load_balancer_health_check_grace_period'),
        max_instance_number=pulumi.get(__response__, 'max_instance_number'),
        min_instance_number=pulumi.get(__response__, 'min_instance_number'),
        multi_az_policy=pulumi.get(__response__, 'multi_az_policy'),
        project_name=pulumi.get(__response__, 'project_name'),
        scaling_group_id=pulumi.get(__response__, 'scaling_group_id'),
        scaling_group_name=pulumi.get(__response__, 'scaling_group_name'),
        scaling_mode=pulumi.get(__response__, 'scaling_mode'),
        server_group_attributes=pulumi.get(__response__, 'server_group_attributes'),
        stopped_instance_count=pulumi.get(__response__, 'stopped_instance_count'),
        subnet_ids=pulumi.get(__response__, 'subnet_ids'),
        suspended_processes=pulumi.get(__response__, 'suspended_processes'),
        tags=pulumi.get(__response__, 'tags'),
        total_instance_count=pulumi.get(__response__, 'total_instance_count'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['CustomDomainArgs', 'CustomDomain']

@pulumi.input_type
class CustomDomainArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[builtins.str],
                 protocols: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 service_id: pulumi.Input[builtins.str],
                 certificate_id: Optional[pulumi.Input[builtins.str]] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_redirect: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a CustomDomain resource.
        :param pulumi.Input[builtins.str] domain: 自定义域名。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] protocols: 协议，取值：HTTP。HTTPS。
        :param pulumi.Input[builtins.str] service_id: 服务ID。
        :param pulumi.Input[builtins.str] certificate_id: 自定义域名证书ID。
        :param pulumi.Input[builtins.str] comments: 备注。
        :param pulumi.Input[builtins.bool] ssl_redirect: 重定向到HTTPS。
        """
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "protocols", protocols)
        pulumi.set(__self__, "service_id", service_id)
        if certificate_id is not None:
            pulumi.set(__self__, "certificate_id", certificate_id)
        if comments is not None:
            pulumi.set(__self__, "comments", comments)
        if ssl_redirect is not None:
            pulumi.set(__self__, "ssl_redirect", ssl_redirect)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[builtins.str]:
        """
        自定义域名。
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def protocols(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        协议，取值：HTTP。HTTPS。
        """
        return pulumi.get(self, "protocols")

    @protocols.setter
    def protocols(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "protocols", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Input[builtins.str]:
        """
        服务ID。
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        自定义域名证书ID。
        """
        return pulumi.get(self, "certificate_id")

    @certificate_id.setter
    def certificate_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "certificate_id", value)

    @property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注。
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comments", value)

    @property
    @pulumi.getter(name="sslRedirect")
    def ssl_redirect(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        重定向到HTTPS。
        """
        return pulumi.get(self, "ssl_redirect")

    @ssl_redirect.setter
    def ssl_redirect(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ssl_redirect", value)


@pulumi.input_type
class _CustomDomainState:
    def __init__(__self__, *,
                 certificate_id: Optional[pulumi.Input[builtins.str]] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 custom_domain_id: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 protocols: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_id: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_redirect: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering CustomDomain resources.
        :param pulumi.Input[builtins.str] certificate_id: 自定义域名证书ID。
        :param pulumi.Input[builtins.str] comments: 备注。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] custom_domain_id: 自定义域名ID。
        :param pulumi.Input[builtins.str] domain: 自定义域名。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] protocols: 协议，取值：HTTP。HTTPS。
        :param pulumi.Input[builtins.str] service_id: 服务ID。
        :param pulumi.Input[builtins.bool] ssl_redirect: 重定向到HTTPS。
        :param pulumi.Input[builtins.str] status: 状态，取值：Creating：配置中。CreationFailed：配置失败。Deleting：删除中。DeletionFailed：删除失败。Verified：正常。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        """
        if certificate_id is not None:
            pulumi.set(__self__, "certificate_id", certificate_id)
        if comments is not None:
            pulumi.set(__self__, "comments", comments)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if custom_domain_id is not None:
            pulumi.set(__self__, "custom_domain_id", custom_domain_id)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if protocols is not None:
            pulumi.set(__self__, "protocols", protocols)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if ssl_redirect is not None:
            pulumi.set(__self__, "ssl_redirect", ssl_redirect)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        自定义域名证书ID。
        """
        return pulumi.get(self, "certificate_id")

    @certificate_id.setter
    def certificate_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "certificate_id", value)

    @property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注。
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comments", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="customDomainId")
    def custom_domain_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        自定义域名ID。
        """
        return pulumi.get(self, "custom_domain_id")

    @custom_domain_id.setter
    def custom_domain_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_domain_id", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        自定义域名。
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def protocols(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        协议，取值：HTTP。HTTPS。
        """
        return pulumi.get(self, "protocols")

    @protocols.setter
    def protocols(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "protocols", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务ID。
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="sslRedirect")
    def ssl_redirect(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        重定向到HTTPS。
        """
        return pulumi.get(self, "ssl_redirect")

    @ssl_redirect.setter
    def ssl_redirect(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ssl_redirect", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        状态，取值：Creating：配置中。CreationFailed：配置失败。Deleting：删除中。DeletionFailed：删除失败。Verified：正常。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:apig/customDomain:CustomDomain")
class CustomDomain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 certificate_id: Optional[pulumi.Input[builtins.str]] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 protocols: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_id: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_redirect: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        服务作为业务对外暴露的入口，可以通过绑定域名功能，将您的自定义域名绑定至服务。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        apig_custom_domain_demo = bytepluscc.apig.CustomDomain("ApigCustomDomainDemo",
            service_id="sd50d3h5xxxm0t5xxxxx",
            domain="www.****.com",
            protocols=[
                "HTTP",
                "HTTPS",
            ],
            certificate_id="cert-775906d873xxx5bc9d1d372b5dxxxxx",
            comments="ApigCustomDomainDemo custom domain",
            ssl_redirect=True)
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:apig/customDomain:CustomDomain example "custom_domain_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] certificate_id: 自定义域名证书ID。
        :param pulumi.Input[builtins.str] comments: 备注。
        :param pulumi.Input[builtins.str] domain: 自定义域名。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] protocols: 协议，取值：HTTP。HTTPS。
        :param pulumi.Input[builtins.str] service_id: 服务ID。
        :param pulumi.Input[builtins.bool] ssl_redirect: 重定向到HTTPS。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CustomDomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        服务作为业务对外暴露的入口，可以通过绑定域名功能，将您的自定义域名绑定至服务。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        apig_custom_domain_demo = bytepluscc.apig.CustomDomain("ApigCustomDomainDemo",
            service_id="sd50d3h5xxxm0t5xxxxx",
            domain="www.****.com",
            protocols=[
                "HTTP",
                "HTTPS",
            ],
            certificate_id="cert-775906d873xxx5bc9d1d372b5dxxxxx",
            comments="ApigCustomDomainDemo custom domain",
            ssl_redirect=True)
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:apig/customDomain:CustomDomain example "custom_domain_id"
        ```

        :param str resource_name: The name of the resource.
        :param CustomDomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomDomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 certificate_id: Optional[pulumi.Input[builtins.str]] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 protocols: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_id: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_redirect: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomDomainArgs.__new__(CustomDomainArgs)

            __props__.__dict__["certificate_id"] = certificate_id
            __props__.__dict__["comments"] = comments
            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            if protocols is None and not opts.urn:
                raise TypeError("Missing required property 'protocols'")
            __props__.__dict__["protocols"] = protocols
            if service_id is None and not opts.urn:
                raise TypeError("Missing required property 'service_id'")
            __props__.__dict__["service_id"] = service_id
            __props__.__dict__["ssl_redirect"] = ssl_redirect
            __props__.__dict__["created_time"] = None
            __props__.__dict__["custom_domain_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(CustomDomain, __self__).__init__(
            'bytepluscc:apig/customDomain:CustomDomain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            certificate_id: Optional[pulumi.Input[builtins.str]] = None,
            comments: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            custom_domain_id: Optional[pulumi.Input[builtins.str]] = None,
            domain: Optional[pulumi.Input[builtins.str]] = None,
            protocols: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            service_id: Optional[pulumi.Input[builtins.str]] = None,
            ssl_redirect: Optional[pulumi.Input[builtins.bool]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'CustomDomain':
        """
        Get an existing CustomDomain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] certificate_id: 自定义域名证书ID。
        :param pulumi.Input[builtins.str] comments: 备注。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] custom_domain_id: 自定义域名ID。
        :param pulumi.Input[builtins.str] domain: 自定义域名。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] protocols: 协议，取值：HTTP。HTTPS。
        :param pulumi.Input[builtins.str] service_id: 服务ID。
        :param pulumi.Input[builtins.bool] ssl_redirect: 重定向到HTTPS。
        :param pulumi.Input[builtins.str] status: 状态，取值：Creating：配置中。CreationFailed：配置失败。Deleting：删除中。DeletionFailed：删除失败。Verified：正常。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CustomDomainState.__new__(_CustomDomainState)

        __props__.__dict__["certificate_id"] = certificate_id
        __props__.__dict__["comments"] = comments
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["custom_domain_id"] = custom_domain_id
        __props__.__dict__["domain"] = domain
        __props__.__dict__["protocols"] = protocols
        __props__.__dict__["service_id"] = service_id
        __props__.__dict__["ssl_redirect"] = ssl_redirect
        __props__.__dict__["status"] = status
        __props__.__dict__["updated_time"] = updated_time
        return CustomDomain(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> pulumi.Output[builtins.str]:
        """
        自定义域名证书ID。
        """
        return pulumi.get(self, "certificate_id")

    @property
    @pulumi.getter
    def comments(self) -> pulumi.Output[builtins.str]:
        """
        备注。
        """
        return pulumi.get(self, "comments")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customDomainId")
    def custom_domain_id(self) -> pulumi.Output[builtins.str]:
        """
        自定义域名ID。
        """
        return pulumi.get(self, "custom_domain_id")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[builtins.str]:
        """
        自定义域名。
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def protocols(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        协议，取值：HTTP。HTTPS。
        """
        return pulumi.get(self, "protocols")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Output[builtins.str]:
        """
        服务ID。
        """
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="sslRedirect")
    def ssl_redirect(self) -> pulumi.Output[builtins.bool]:
        """
        重定向到HTTPS。
        """
        return pulumi.get(self, "ssl_redirect")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        状态，取值：Creating：配置中。CreationFailed：配置失败。Deleting：删除中。DeletionFailed：删除失败。Verified：正常。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CertificateArgs', 'Certificate']

@pulumi.input_type
class CertificateArgs:
    def __init__(__self__, *,
                 certificate_type: pulumi.Input[builtins.str],
                 public_key: pulumi.Input[builtins.str],
                 certificate_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 private_key: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['CertificateTagArgs']]]] = None):
        """
        The set of arguments for constructing a Certificate resource.
        :param pulumi.Input[builtins.str] certificate_type: 证书类型，取值：CA：CA证书、Server：服务器证书。
        :param pulumi.Input[builtins.str] public_key: 服务器证书的公钥。
        :param pulumi.Input[builtins.str] certificate_name: 证书名称，长度限制为1 ～ 128个字符，必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。
        :param pulumi.Input[builtins.str] description: 证书描述。
        :param pulumi.Input[builtins.str] private_key: 服务器证书的私钥，当证书类型为Server时必填。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        """
        pulumi.set(__self__, "certificate_type", certificate_type)
        pulumi.set(__self__, "public_key", public_key)
        if certificate_name is not None:
            pulumi.set(__self__, "certificate_name", certificate_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="certificateType")
    def certificate_type(self) -> pulumi.Input[builtins.str]:
        """
        证书类型，取值：CA：CA证书、Server：服务器证书。
        """
        return pulumi.get(self, "certificate_type")

    @certificate_type.setter
    def certificate_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "certificate_type", value)

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> pulumi.Input[builtins.str]:
        """
        服务器证书的公钥。
        """
        return pulumi.get(self, "public_key")

    @public_key.setter
    def public_key(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "public_key", value)

    @property
    @pulumi.getter(name="certificateName")
    def certificate_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        证书名称，长度限制为1 ～ 128个字符，必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。
        """
        return pulumi.get(self, "certificate_name")

    @certificate_name.setter
    def certificate_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "certificate_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        证书描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器证书的私钥，当证书类型为Server时必填。
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CertificateTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CertificateTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _CertificateState:
    def __init__(__self__, *,
                 certificate_id: Optional[pulumi.Input[builtins.str]] = None,
                 certificate_name: Optional[pulumi.Input[builtins.str]] = None,
                 certificate_type: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 domain_name: Optional[pulumi.Input[builtins.str]] = None,
                 expired_at: Optional[pulumi.Input[builtins.str]] = None,
                 listeners: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 private_key: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 san: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['CertificateTagArgs']]]] = None):
        """
        Input properties used for looking up and filtering Certificate resources.
        :param pulumi.Input[builtins.str] certificate_id: 证书ID。
        :param pulumi.Input[builtins.str] certificate_name: 证书名称，长度限制为1 ～ 128个字符，必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。
        :param pulumi.Input[builtins.str] certificate_type: 证书类型，取值：CA：CA证书、Server：服务器证书。
        :param pulumi.Input[builtins.str] created_time: 证书创建时间。
        :param pulumi.Input[builtins.str] description: 证书描述。
        :param pulumi.Input[builtins.str] domain_name: 证书域名。
        :param pulumi.Input[builtins.str] expired_at: 证书过期时间。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] listeners: 证书关联的监听器列表。
        :param pulumi.Input[builtins.str] private_key: 服务器证书的私钥，当证书类型为Server时必填。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] public_key: 服务器证书的公钥。
        :param pulumi.Input[builtins.str] san: 证书扩展域名列表，用英文',' 分隔多个域名， 包含(commonName,DnsName,IP)。
        :param pulumi.Input[builtins.str] status: 证书的状态，取值为：Creating：创建中。Active：运行中。Deleting：删除中。
        """
        if certificate_id is not None:
            pulumi.set(__self__, "certificate_id", certificate_id)
        if certificate_name is not None:
            pulumi.set(__self__, "certificate_name", certificate_name)
        if certificate_type is not None:
            pulumi.set(__self__, "certificate_type", certificate_type)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if domain_name is not None:
            pulumi.set(__self__, "domain_name", domain_name)
        if expired_at is not None:
            pulumi.set(__self__, "expired_at", expired_at)
        if listeners is not None:
            pulumi.set(__self__, "listeners", listeners)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if public_key is not None:
            pulumi.set(__self__, "public_key", public_key)
        if san is not None:
            pulumi.set(__self__, "san", san)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        证书ID。
        """
        return pulumi.get(self, "certificate_id")

    @certificate_id.setter
    def certificate_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "certificate_id", value)

    @property
    @pulumi.getter(name="certificateName")
    def certificate_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        证书名称，长度限制为1 ～ 128个字符，必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。
        """
        return pulumi.get(self, "certificate_name")

    @certificate_name.setter
    def certificate_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "certificate_name", value)

    @property
    @pulumi.getter(name="certificateType")
    def certificate_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        证书类型，取值：CA：CA证书、Server：服务器证书。
        """
        return pulumi.get(self, "certificate_type")

    @certificate_type.setter
    def certificate_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "certificate_type", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        证书创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        证书描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        证书域名。
        """
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain_name", value)

    @property
    @pulumi.getter(name="expiredAt")
    def expired_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        证书过期时间。
        """
        return pulumi.get(self, "expired_at")

    @expired_at.setter
    def expired_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expired_at", value)

    @property
    @pulumi.getter
    def listeners(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        证书关联的监听器列表。
        """
        return pulumi.get(self, "listeners")

    @listeners.setter
    def listeners(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "listeners", value)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器证书的私钥，当证书类型为Server时必填。
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器证书的公钥。
        """
        return pulumi.get(self, "public_key")

    @public_key.setter
    def public_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "public_key", value)

    @property
    @pulumi.getter
    def san(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        证书扩展域名列表，用英文',' 分隔多个域名， 包含(commonName,DnsName,IP)。
        """
        return pulumi.get(self, "san")

    @san.setter
    def san(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "san", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        证书的状态，取值为：Creating：创建中。Active：运行中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CertificateTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CertificateTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("bytepluscc:alb/certificate:Certificate")
class Certificate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 certificate_name: Optional[pulumi.Input[builtins.str]] = None,
                 certificate_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 private_key: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CertificateTagArgs', 'CertificateTagArgsDict']]]]] = None,
                 __props__=None):
        """
        ALB 支持上传服务器证书、CA 证书到控制台，对上传的证书单独管理。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        a_lb_certificate_demo = bytepluscc.alb.Certificate("ALBCertificateDemo",
            certificate_name="ALBCertificateDemo",
            certificate_type="CA",
            public_key="-----BEGIN CERTIFICATE-----xxxx-----END CERTIFICATE-----",
            description="ALBCertificateDemo description",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:alb/certificate:Certificate example "certificate_id|certificate_type"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] certificate_name: 证书名称，长度限制为1 ～ 128个字符，必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。
        :param pulumi.Input[builtins.str] certificate_type: 证书类型，取值：CA：CA证书、Server：服务器证书。
        :param pulumi.Input[builtins.str] description: 证书描述。
        :param pulumi.Input[builtins.str] private_key: 服务器证书的私钥，当证书类型为Server时必填。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] public_key: 服务器证书的公钥。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CertificateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ALB 支持上传服务器证书、CA 证书到控制台，对上传的证书单独管理。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        a_lb_certificate_demo = bytepluscc.alb.Certificate("ALBCertificateDemo",
            certificate_name="ALBCertificateDemo",
            certificate_type="CA",
            public_key="-----BEGIN CERTIFICATE-----xxxx-----END CERTIFICATE-----",
            description="ALBCertificateDemo description",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:alb/certificate:Certificate example "certificate_id|certificate_type"
        ```

        :param str resource_name: The name of the resource.
        :param CertificateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CertificateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 certificate_name: Optional[pulumi.Input[builtins.str]] = None,
                 certificate_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 private_key: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CertificateTagArgs', 'CertificateTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CertificateArgs.__new__(CertificateArgs)

            __props__.__dict__["certificate_name"] = certificate_name
            if certificate_type is None and not opts.urn:
                raise TypeError("Missing required property 'certificate_type'")
            __props__.__dict__["certificate_type"] = certificate_type
            __props__.__dict__["description"] = description
            __props__.__dict__["private_key"] = private_key
            __props__.__dict__["project_name"] = project_name
            if public_key is None and not opts.urn:
                raise TypeError("Missing required property 'public_key'")
            __props__.__dict__["public_key"] = public_key
            __props__.__dict__["tags"] = tags
            __props__.__dict__["certificate_id"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["domain_name"] = None
            __props__.__dict__["expired_at"] = None
            __props__.__dict__["listeners"] = None
            __props__.__dict__["san"] = None
            __props__.__dict__["status"] = None
        super(Certificate, __self__).__init__(
            'bytepluscc:alb/certificate:Certificate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            certificate_id: Optional[pulumi.Input[builtins.str]] = None,
            certificate_name: Optional[pulumi.Input[builtins.str]] = None,
            certificate_type: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            domain_name: Optional[pulumi.Input[builtins.str]] = None,
            expired_at: Optional[pulumi.Input[builtins.str]] = None,
            listeners: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            private_key: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            public_key: Optional[pulumi.Input[builtins.str]] = None,
            san: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CertificateTagArgs', 'CertificateTagArgsDict']]]]] = None) -> 'Certificate':
        """
        Get an existing Certificate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] certificate_id: 证书ID。
        :param pulumi.Input[builtins.str] certificate_name: 证书名称，长度限制为1 ～ 128个字符，必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。
        :param pulumi.Input[builtins.str] certificate_type: 证书类型，取值：CA：CA证书、Server：服务器证书。
        :param pulumi.Input[builtins.str] created_time: 证书创建时间。
        :param pulumi.Input[builtins.str] description: 证书描述。
        :param pulumi.Input[builtins.str] domain_name: 证书域名。
        :param pulumi.Input[builtins.str] expired_at: 证书过期时间。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] listeners: 证书关联的监听器列表。
        :param pulumi.Input[builtins.str] private_key: 服务器证书的私钥，当证书类型为Server时必填。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] public_key: 服务器证书的公钥。
        :param pulumi.Input[builtins.str] san: 证书扩展域名列表，用英文',' 分隔多个域名， 包含(commonName,DnsName,IP)。
        :param pulumi.Input[builtins.str] status: 证书的状态，取值为：Creating：创建中。Active：运行中。Deleting：删除中。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CertificateState.__new__(_CertificateState)

        __props__.__dict__["certificate_id"] = certificate_id
        __props__.__dict__["certificate_name"] = certificate_name
        __props__.__dict__["certificate_type"] = certificate_type
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["domain_name"] = domain_name
        __props__.__dict__["expired_at"] = expired_at
        __props__.__dict__["listeners"] = listeners
        __props__.__dict__["private_key"] = private_key
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["public_key"] = public_key
        __props__.__dict__["san"] = san
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        return Certificate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> pulumi.Output[builtins.str]:
        """
        证书ID。
        """
        return pulumi.get(self, "certificate_id")

    @property
    @pulumi.getter(name="certificateName")
    def certificate_name(self) -> pulumi.Output[builtins.str]:
        """
        证书名称，长度限制为1 ～ 128个字符，必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。
        """
        return pulumi.get(self, "certificate_name")

    @property
    @pulumi.getter(name="certificateType")
    def certificate_type(self) -> pulumi.Output[builtins.str]:
        """
        证书类型，取值：CA：CA证书、Server：服务器证书。
        """
        return pulumi.get(self, "certificate_type")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        证书创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        证书描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> pulumi.Output[builtins.str]:
        """
        证书域名。
        """
        return pulumi.get(self, "domain_name")

    @property
    @pulumi.getter(name="expiredAt")
    def expired_at(self) -> pulumi.Output[builtins.str]:
        """
        证书过期时间。
        """
        return pulumi.get(self, "expired_at")

    @property
    @pulumi.getter
    def listeners(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        证书关联的监听器列表。
        """
        return pulumi.get(self, "listeners")

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> pulumi.Output[builtins.str]:
        """
        服务器证书的私钥，当证书类型为Server时必填。
        """
        return pulumi.get(self, "private_key")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> pulumi.Output[builtins.str]:
        """
        服务器证书的公钥。
        """
        return pulumi.get(self, "public_key")

    @property
    @pulumi.getter
    def san(self) -> pulumi.Output[builtins.str]:
        """
        证书扩展域名列表，用英文',' 分隔多个域名， 包含(commonName,DnsName,IP)。
        """
        return pulumi.get(self, "san")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        证书的状态，取值为：Creating：创建中。Active：运行中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.CertificateTag']]:
        return pulumi.get(self, "tags")

